import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { TriggerNotificationOptions, ResolveNotificationConfigResponse, UpsertNotificationConfig, UpsertNotificationConfigResponse, NotificationConfigCreatedEnvelope, NotificationConfigUpdatedEnvelope } from './index.typings.js';
export { ActionEvent, Address, AddressLocation, AddressStreetOneOf, Agenda, Alignment, AnchorData, AppEmbedData, AppEmbedDataAppDataOneOf, AppType, AspectRatio, AudioData, Background, BackgroundBackgroundOneOf, BackgroundType, Badge, BaseEventMetadata, BlockquoteData, BookingData, Border, BorderColors, BulletedListData, ButtonData, ButtonDataType, ButtonStyles, CalendarLinks, CaptionData, CardStyles, CardStylesType, Category, CategoryCounts, CellStyle, CheckIn, CheckoutFormMessages, CodeBlockData, CollapsibleListData, ColorData, Colors, CommonAddress, CommonAddressLocation, CommonAddressStreetOneOf, CommonStreetAddress, CommonSubdivision, ConferenceType, CouponDiscount, Crop, Dashboard, Decoration, DecorationDataOneOf, DecorationType, Design, Dimensions, Direction, Discount, DiscountItem, DiscountItemDiscountOneOf, DividerData, DividerDataAlignment, DocumentStyle, DomainEvent, DomainEventBodyOneOf, EmailNotificationConfig, EmailNotificationReminderTime, EmailNotificationType, EmailTemplate, EmbedData, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, Event, EventCanceled, EventCopied, EventData, EventDeleted, EventDisplaySettings, EventEnded, EventGuests, EventMetadata, EventReminder, EventStarted, EventStatus, EventType, EventUpdated, ExternalEvent, Fee, FeeName, FeeType, Feed, FileData, FileSource, FileSourceDataOneOf, FontSizeData, FontType, Form, FormMessages, FormResponse, FormattedAddress, GIF, GIFData, GIFType, GalleryData, GalleryDataItem, GalleryDataItemDataOneOf, GalleryOptions, GalleryOptionsLayout, Gradient, GuestListConfig, HTMLData, HTMLDataDataOneOf, HeadingData, Height, IdentificationData, IdentificationDataIdOneOf, Image, ImageData, ImageDataStyles, ImageStyles, InitialExpandedItems, Input, InputControl, InputControlType, InputValue, Invoice, Item, ItemStyle, Keyword, Label, LabellingSettings, Layout, LayoutCellData, LayoutType, LineStyle, Link, LinkData, LinkPreviewData, LinkPreviewDataStyles, ListValue, Location, LocationType, MapCoordinates, MapData, MapSettings, MapType, Media, MentionData, MessageEnvelope, Metadata, Money, Negative, NegativeResponseConfirmation, Node, NodeDataOneOf, NodeStyle, NodeType, NotificationConfig, NullValue, Occurrence, Oembed, OnlineConferencing, OnlineConferencingConfig, OnlineConferencingLogin, OnlineConferencingSession, Option, OptionDesign, OptionLayout, OptionSelection, OptionSelectionSelectedOptionOneOf, OrderCanceled, OrderConfirmed, OrderEmailAdded, OrderGuest, OrderPaid, OrderStatus, OrderedListData, Orientation, PDFSettings, PaidPlanDiscount, PaidPlanDiscountDiscountOneOf, ParagraphData, PercentDiscount, Permissions, Placement, PlaybackOptions, PluginContainerData, PluginContainerDataAlignment, PluginContainerDataWidth, PluginContainerDataWidthDataOneOf, Poll, PollData, PollDataLayout, PollDesign, PollLayout, PollLayoutDirection, PollLayoutType, PollSettings, Position, Positive, PositiveResponseConfirmation, PushNotificationType, Recurrences, Registration, RegistrationClosedMessages, RegistrationStatus, Rel, Resizing, ResolveEmailNotificationConfigRequest, ResolveEmailNotificationConfigResponse, ResolveNotificationConfigRequest, ResponseConfirmation, RestoreInfo, RibbonStyles, RichContent, RsvpCollection, RsvpCollectionConfig, RsvpFormMessages, RsvpGuest, RsvpStatusOptions, RsvpSummary, ScheduleConfig, Scheduling, SeoSchema, SeoSettings, Settings, SiteUrl, Source, Spoiler, SpoilerData, StandardDetails, State, Status, StreetAddress, Styles, StylesBorder, StylesPosition, Subdivision, SubdivisionType, TableCellData, TableData, Tag, Target, Tax, TaxConfig, TaxType, TextAlignment, TextData, TextNodeStyle, TextStyle, Thumbnails, ThumbnailsAlignment, Ticket, TicketGuest, TicketPdfResolveDelayed, TicketPdfResolved, Ticketing, TicketingConfig, TicketingSummary, TicketsUnavailableMessages, TimeDuration, TriggerNotificationOptionsGuestsOneOf, TriggerNotificationOptionsNotificationOneOf, TriggerNotificationRequest, TriggerNotificationRequestGuestsOneOf, TriggerNotificationRequestNotificationOneOf, TriggerNotificationResponse, Type, UpsertNotificationConfigRequest, V1Link, V1LinkDataOneOf, ValueType, VerticalAlignment, Video, VideoData, ViewMode, ViewRole, VisitorType, VoteRole, WebhookIdentityType, Width, WidthType } from './index.typings.js';

type NotificationConfigNonNullablePaths = `rsvpConfirmation.notificationType` | `rsvpConfirmation.reminderTime` | `newSpotsAvailable.notificationType` | `newSpotsAvailable.reminderTime` | `eventCancelation.notificationType` | `eventCancelation.reminderTime` | `upcomingEventReminder.notificationType` | `upcomingEventReminder.reminderTime` | `orderConfirmation.notificationType` | `orderConfirmation.reminderTime` | `ticketConfirmation.notificationType` | `ticketConfirmation.reminderTime` | `invoice.notificationType` | `invoice.reminderTime` | `orderConfirmationWithTicketsLink.notificationType` | `orderConfirmationWithTicketsLink.reminderTime`;
declare function triggerNotification$1(httpClient: HttpClient): TriggerNotificationSignature;
interface TriggerNotificationSignature {
    /**
     * Triggers notification
     */
    (options: TriggerNotificationOptions): Promise<void>;
}
declare function resolveNotificationConfig$1(httpClient: HttpClient): ResolveNotificationConfigSignature;
interface ResolveNotificationConfigSignature {
    /**
     * Resolves a NotificationConfig by id. Returns saved value or default value if not saved yet.
     * @param - Id of the NotificationConfig to retrieve
     */
    (notificationConfigId: string): Promise<NonNullablePaths<ResolveNotificationConfigResponse, {
        [P in NotificationConfigNonNullablePaths]: `notificationConfig.${P}`;
    }[NotificationConfigNonNullablePaths]>>;
}
declare function upsertNotificationConfig$1(httpClient: HttpClient): UpsertNotificationConfigSignature;
interface UpsertNotificationConfigSignature {
    /**
     * Upsert a NotificationConfig
     * @param - Event ID.
     */
    (_id: string, notificationConfig: UpsertNotificationConfig): Promise<NonNullablePaths<UpsertNotificationConfigResponse, {
        [P in NotificationConfigNonNullablePaths]: `notificationConfig.${P}`;
    }[NotificationConfigNonNullablePaths]>>;
}
declare const onNotificationConfigCreated$1: EventDefinition<NotificationConfigCreatedEnvelope, "wix.events.notifications.v2.notification_config_created">;
declare const onNotificationConfigUpdated$1: EventDefinition<NotificationConfigUpdatedEnvelope, "wix.events.notifications.v2.notification_config_updated">;

declare const triggerNotification: MaybeContext<BuildRESTFunction<typeof triggerNotification$1> & typeof triggerNotification$1>;
declare const resolveNotificationConfig: MaybeContext<BuildRESTFunction<typeof resolveNotificationConfig$1> & typeof resolveNotificationConfig$1>;
declare const upsertNotificationConfig: MaybeContext<BuildRESTFunction<typeof upsertNotificationConfig$1> & typeof upsertNotificationConfig$1>;
/** */
declare const onNotificationConfigCreated: BuildEventDefinition<typeof onNotificationConfigCreated$1>;
/** */
declare const onNotificationConfigUpdated: BuildEventDefinition<typeof onNotificationConfigUpdated$1>;

export { NotificationConfigCreatedEnvelope, NotificationConfigUpdatedEnvelope, ResolveNotificationConfigResponse, TriggerNotificationOptions, UpsertNotificationConfig, UpsertNotificationConfigResponse, onNotificationConfigCreated, onNotificationConfigUpdated, resolveNotificationConfig, triggerNotification, upsertNotificationConfig };
